@@ -189,6 +189,8 @@ namespace Banshee.Collection.Database
                 TagLib.File file = StreamTagger.ProcessUri (uri);
                 track = new DatabaseTrackInfo ();
                 StreamTagger.TrackInfoMerge (track, file);
+                
+                track.DateAdded = DateTime.Now;
                 track.PrimarySource = trackPrimarySourceChooser (track);
 
                 if (track.PrimarySource is Banshee.Library.LibrarySource) {
@@ -237,10 +239,10 @@ namespace Banshee.Collection.Database
             counts.Clear ();
         }
 
-        protected override void OnFinished ()
+        protected override void OnImportFinished ()
         {
             NotifyAllSources ();
-            base.OnFinished ();
+            base.OnImportFinished ();
         }
     }
 }
