@@ -52,8 +52,8 @@ namespace Banshee.Database
         // NOTE: Whenever there is a change in ANY of the database schema,
         //       this version MUST be incremented and a migration method
         //       MUST be supplied to match the new version number
-        protected const int CURRENT_VERSION = 11;
-        protected const int CURRENT_METADATA_VERSION = 1;
+        protected const int CURRENT_VERSION = 17;
+        protected const int CURRENT_METADATA_VERSION = 2;
         
 #region Migration Driver
         
@@ -407,6 +407,81 @@ namespace Banshee.Database
         
 #endregion
 
+#region Version 12
+
+        [DatabaseVersion (12)]
+        private bool Migrate_12 ()
+        {
+            Execute ("ALTER TABLE CoreAlbums ADD COLUMN ArtistName STRING");
+            Execute ("ALTER TABLE CoreAlbums ADD COLUMN ArtistNameLowered STRING");
+            return true;
+        }
+        
+#endregion
+
+#region Version 13
+
+        [DatabaseVersion (13)]
+        private bool Migrate_13 ()
+        {
+            Execute("CREATE INDEX CoreAlbumsArtistIndex ON CoreAlbums(TitleLowered, ArtistNameLowered)");
+            Execute("CREATE INDEX CoreTracksUriIndex ON CoreTracks(PrimarySourceID, Uri)");
+            return true;
+        }
+        
+#endregion
+
+#region Version 14
+
+        [DatabaseVersion (14)]
+        private bool Migrate_14 ()
+        {
+            InitializeOrderedTracks ();
+            return true;
+        }
+        
+#endregion
+
+#region Version 15
+
+        [DatabaseVersion (15)]
+        private bool Migrate_15 ()
+        {
+            string [] columns = new string [] {"Genre", "Composer", "Copyright", "LicenseUri", "Comment"};
+            foreach (string column in columns) {
+                Execute (String.Format ("UPDATE CoreTracks SET {0} = NULL WHERE {0} IS NOT NULL AND trim({0}) = ''", column));
+            }
+            return true;
+        }
+        
+#endregion
+
+#region Version 16
+
+        [DatabaseVersion (16)]
+        private bool Migrate_16 ()
+        {
+            // The CoreCache table is now created as needed, and as a TEMP table
+            Execute ("DROP TABLE CoreCache");
+            Execute ("COMMIT; VACUUM; BEGIN");
+            Execute ("ANALYZE");
+            return true;
+        }
+        
+#endregion
+        
+#region Version 17
+
+        [DatabaseVersion (17)]
+        private bool Migrate_17 ()
+        {
+            Execute ("CREATE INDEX CoreTracksCoverArtIndex ON CoreTracks (PrimarySourceID, AlbumID, DateUpdatedStamp)");
+            Execute ("ANALYZE");
+            return true;
+        }
+        
+#endregion
+
 #pragma warning restore 0169
         
 #region Fresh database setup
@@ -433,7 +508,7 @@ namespace Banshee.Database
                 )
             ");
             Execute (String.Format ("INSERT INTO CoreConfiguration VALUES (null, 'DatabaseVersion', {0})", CURRENT_VERSION));
-            Execute ("INSERT INTO CoreConfiguration VALUES (null, 'MetadataVersion', 0)");
+            Execute (String.Format ("INSERT INTO CoreConfiguration VALUES (null, 'MetadataVersion', {0})", CURRENT_METADATA_VERSION));
             
             Execute(@"
                 CREATE TABLE CorePrimarySources (
@@ -490,6 +565,8 @@ namespace Banshee.Database
             Execute("CREATE INDEX CoreTracksPrimarySourceIndex ON CoreTracks(ArtistID, AlbumID, PrimarySourceID, Disc, TrackNumber, Uri)");
             Execute("CREATE INDEX CoreTracksAggregatesIndex ON CoreTracks(FileSize, Duration)");
             Execute("CREATE INDEX CoreTracksExternalIDIndex ON CoreTracks(PrimarySourceID, ExternalID)");
+            Execute("CREATE INDEX CoreTracksUriIndex ON CoreTracks(PrimarySourceID, Uri)");
+            Execute("CREATE INDEX CoreTracksCoverArtIndex ON CoreTracks (PrimarySourceID, AlbumID, DateUpdatedStamp)");
             
             Execute(@"
                 CREATE TABLE CoreAlbums (
@@ -506,10 +583,14 @@ namespace Banshee.Database
                     Duration            INTEGER,
                     Year                INTEGER,
                     
+                    ArtistName          TEXT,
+                    ArtistNameLowered   TEXT,
+                    
                     Rating              INTEGER
                 )
             ");
             Execute("CREATE INDEX CoreAlbumsIndex       ON CoreAlbums(ArtistID, TitleLowered)");
+            Execute("CREATE INDEX CoreAlbumsArtistIndex       ON CoreAlbums(TitleLowered, ArtistNameLowered)");
 
             Execute(@"
                 CREATE TABLE CoreArtists (
@@ -581,14 +662,6 @@ namespace Banshee.Database
                     ModelID             TEXT
                 )
             ");
-            
-            Execute(@"
-                CREATE TABLE CoreCache (
-                    OrderID             INTEGER PRIMARY KEY,
-                    ModelID             INTEGER,
-                    ItemID              INTEGER
-                )
-            ");
 
             // This index slows down queries were we shove data into the CoreCache.
             // Since we do that frequently, not using it.
@@ -615,7 +688,7 @@ namespace Banshee.Database
                             FROM CoreArtists 
                             WHERE Name = Tracks.Artist
                             LIMIT 1),
-                        0, null, AlbumTitle, NULL, ReleaseDate, 0, 0, 0
+                        0, null, AlbumTitle, NULL, ReleaseDate, 0, 0, Artist, NULL, 0
                         FROM Tracks
                         ORDER BY AlbumTitle
             ");
@@ -660,31 +733,66 @@ namespace Banshee.Database
                         FROM Tracks
             ", (int)TrackMediaAttributes.Default, (int)StreamPlaybackError.None));
 
-            Execute ("update coretracks set lastplayedstamp = NULL where lastplayedstamp = -62135575200");
+            Execute ("UPDATE CoreTracks SET LastPlayedStamp = NULL WHERE LastPlayedStamp = -62135575200");
 
-            Execute(@"
-                INSERT INTO CorePlaylists (PlaylistID, Name, SortColumn, SortType)
-                    SELECT * FROM Playlists
-            ");
+            // Old versions of Banshee had different columns for Playlists/PlaylistEntries, so be careful
+            try {
+                Execute(@"
+                    INSERT INTO CorePlaylists (PlaylistID, Name, SortColumn, SortType)
+                        SELECT * FROM Playlists;
+                    INSERT INTO CorePlaylistEntries
+                        SELECT * FROM PlaylistEntries
+                ");
+            } catch (Exception e) {
+                Log.Exception ("Must be a pre-0.13.2 banshee.db, attempting to migrate", e);
+                try {
+                    Execute(@"
+                        INSERT INTO CorePlaylists (PlaylistID, Name)
+                            SELECT PlaylistID, Name FROM Playlists;
+                        INSERT INTO CorePlaylistEntries (EntryID, PlaylistID, TrackID)
+                            SELECT EntryID, PlaylistID, TrackID FROM PlaylistEntries
+                    ");
+                    Log.Debug ("Success, was able to migrate older playlist information");
+                } catch (Exception e2) {
+                    Log.Exception ("Failed to migrate playlists", e2);
+                }
+            }
 
-            Execute(@"
-                INSERT INTO CorePlaylistEntries
-                    SELECT * FROM PlaylistEntries
-            ");
 
-            Execute(@"
-                INSERT INTO CoreSmartPlaylists (SmartPlaylistID, Name, Condition, OrderBy, LimitNumber, LimitCriterion)
-                    SELECT * FROM SmartPlaylists
-            ");
+            // Really old versions of Banshee didn't have SmartPlaylists, so ignore errors
+            try {
+                Execute(@"
+                    INSERT INTO CoreSmartPlaylists (SmartPlaylistID, Name, Condition, OrderBy, LimitNumber, LimitCriterion)
+                        SELECT * FROM SmartPlaylists
+                ");
+            } catch {}
 
             Execute ("UPDATE CoreSmartPlaylists SET PrimarySourceID = 1");
             Execute ("UPDATE CorePlaylists SET PrimarySourceID = 1");
+            
+            InitializeOrderedTracks ();
+            Migrate_15 ();
         }
 
 #endregion
 
 #region Utilities / Source / Service Stuff
 
+        private void InitializeOrderedTracks ()
+        {
+            foreach (long playlist_id in connection.QueryEnumerable<long> ("SELECT PlaylistID FROM CorePlaylists ORDER BY PlaylistID")) {
+                if (connection.Query<long> (@"SELECT COUNT(*) FROM CorePlaylistEntries 
+                    WHERE PlaylistID = ? AND ViewOrder > 0", playlist_id) <= 0) {
+                
+                    long first_id = connection.Query<long> ("SELECT COUNT(*) FROM CorePlaylistEntries WHERE PlaylistID < ?", playlist_id);
+                    connection.Execute (
+                        @"UPDATE CorePlaylistEntries SET ViewOrder = (ROWID - ?) WHERE PlaylistID = ?",
+                        first_id, playlist_id
+                    );
+                }
+            }
+        }
+
         private void OnServiceStarted (ServiceStartedArgs args)
         {
             if (args.Service is UserJobManager) {
@@ -759,27 +867,25 @@ namespace Banshee.Database
                     try {
                         track = DatabaseTrackInfo.Provider.Load (reader);
 
-                        if (track == null || track.Uri == null || !track.Uri.IsFile)
-                            continue;
-                        
-                        try {
-                            TagLib.File file = StreamTagger.ProcessUri (track.Uri);
-                            StreamTagger.TrackInfoMerge (track, file, true);
-                        } catch (Exception e) {
-                            Log.Warning (String.Format ("Failed to update metadata for {0}", track),
-                                e.GetType ().ToString (), false);
+                        if (track != null && track.Uri != null && track.Uri.IsFile) {
+                            try {
+                                TagLib.File file = StreamTagger.ProcessUri (track.Uri);
+                                StreamTagger.TrackInfoMerge (track, file, true);
+                            } catch (Exception e) {
+                                Log.Warning (String.Format ("Failed to update metadata for {0}", track),
+                                    e.GetType ().ToString (), false);
+                            }
+                            
+                            track.Save (false);
+                            track.Artist.Save ();
+                            track.Album.Save ();
+
+                            job.Status = String.Format ("{0} - {1}", track.DisplayArtistName, track.DisplayTrackTitle);
                         }
-                        
-                        track.Save (false);
-                        track.Artist.Save ();
-                        track.Album.Save ();
                     } catch (Exception e) {
                         Log.Warning (String.Format ("Failed to update metadata for {0}", track), e.ToString (), false);
-                        job.Finish ();
-                        throw;
                     }
 
-                    job.Status = String.Format ("{0} - {1}", track.DisplayArtistName, track.DisplayTrackTitle);
                     job.Progress = (double)++count / (double)total;
                 }
             }
