@@ -47,24 +47,18 @@ namespace Banshee.MediaEngine
 {
     public delegate bool TrackInterceptHandler (TrackInfo track);
 
-    public class PlayerEngineService : IInitializeService, IDelayedInitializeService,
-        IRequiredService, IPlayerEngineService, IDisposable
-    {
+    public class PlayerEngineService : IInitializeService, IRequiredService, IPlayerEngineService, IDisposable
+    {   
         private List<PlayerEngine> engines = new List<PlayerEngine> ();
         private PlayerEngine active_engine;
         private PlayerEngine default_engine;
         private PlayerEngine pending_engine;
-        private object pending_playback_for_not_ready;
-        private bool pending_playback_for_not_ready_play;
-        private TrackInfo synthesized_contacting_track;
 
         private string preferred_engine_id = null;
 
         public event EventHandler PlayWhenIdleRequest;
         public event TrackInterceptHandler TrackIntercept;
-        public event Action<PlayerEngine> EngineBeforeInitialize;
-        public event Action<PlayerEngine> EngineAfterInitialize;
-
+        
         private event DBusPlayerEventHandler dbus_event_changed;
         event DBusPlayerEventHandler IPlayerEngineService.EventChanged {
             add { dbus_event_changed += value; }
@@ -76,30 +70,30 @@ namespace Banshee.MediaEngine
             add { dbus_state_changed += value; }
             remove { dbus_state_changed -= value; }
         }
-
+        
         public PlayerEngineService ()
         {
         }
-
-        void IInitializeService.Initialize ()
+        
+        public void Initialize ()
         {
             preferred_engine_id = EngineSchema.Get();
-
+            
             if (default_engine == null && engines.Count > 0) {
                 default_engine = engines[0];
             }
-
+            
             foreach (TypeExtensionNode node in AddinManager.GetExtensionNodes ("/Banshee/MediaEngine/PlayerEngine")) {
                 LoadEngine (node);
             }
-
+            
             if (default_engine != null) {
                 active_engine = default_engine;
                 Log.Debug (Catalog.GetString ("Default player engine"), active_engine.Name);
             } else {
                 default_engine = active_engine;
             }
-
+            
             if (default_engine == null || active_engine == null || engines == null || engines.Count == 0) {
                 Log.Warning (Catalog.GetString (
                     "No player engines were found. Please ensure Banshee has been cleanly installed."),
@@ -109,50 +103,19 @@ namespace Banshee.MediaEngine
                 active_engine = null_engine;
                 default_engine = null_engine;
             }
-
+            
             MetadataService.Instance.HaveResult += OnMetadataServiceHaveResult;
-
-            TrackInfo.IsPlayingMethod = track => IsPlaying (track) &&
-                track.CacheModelId == CurrentTrack.CacheModelId &&
-                (track.CacheEntryId == null || track.CacheEntryId.Equals (CurrentTrack.CacheEntryId));
+            
+            TrackInfo.IsPlayingMethod = IsPlaying;
         }
-
-        private void InitializeEngine (PlayerEngine engine)
-        {
-            var handler = EngineBeforeInitialize;
-            if (handler != null) {
-                handler (engine);
-            }
-
-            engine.Initialize ();
-            engine.IsInitialized = true;
-
-            handler = EngineAfterInitialize;
-            if (handler != null) {
-                handler (engine);
-            }
-        }
-
-        void IDelayedInitializeService.DelayedInitialize ()
-        {
-            foreach (var engine in Engines) {
-                if (engine.DelayedInitialize) {
-                    InitializeEngine (engine);
-                }
-            }
-        }
-
+        
         private void LoadEngine (TypeExtensionNode node)
         {
             LoadEngine ((PlayerEngine) node.CreateInstance (typeof (PlayerEngine)));
         }
-
+        
         private void LoadEngine (PlayerEngine engine)
         {
-            if (!engine.DelayedInitialize) {
-                InitializeEngine (engine);
-            }
-
             engine.EventChanged += OnEngineEventChanged;
 
             if (engine.Id == preferred_engine_id) {
@@ -168,31 +131,31 @@ namespace Banshee.MediaEngine
         public void Dispose ()
         {
             MetadataService.Instance.HaveResult -= OnMetadataServiceHaveResult;
-
+            
             foreach (PlayerEngine engine in engines) {
                 engine.Dispose ();
             }
-
+            
             active_engine = null;
             default_engine = null;
             pending_engine = null;
-
+            
             preferred_engine_id = null;
-
+            
             engines.Clear ();
         }
-
+        
         private void OnMetadataServiceHaveResult (object o, MetadataLookupResultArgs args)
         {
-            if (CurrentTrack != null && CurrentTrack.TrackEqual (args.Track as TrackInfo)) {
+            if (CurrentTrack != null && args.Track == CurrentTrack) {
                 foreach (StreamTag tag in args.ResultTags) {
                     StreamTagger.TrackInfoMerge (CurrentTrack, tag);
                 }
-
+                
                 OnEngineEventChanged (new PlayerEventArgs (PlayerEvent.TrackInfoUpdated));
             }
         }
-
+        
         private void HandleStateChange (PlayerEventStateChangeArgs args)
         {
             if (args.Current == PlayerState.Loaded && CurrentTrack != null) {
@@ -200,17 +163,28 @@ namespace Banshee.MediaEngine
                 MetadataService.Instance.Lookup (CurrentTrack);
             } else if (args.Current == PlayerState.Ready) {
                 // Enable our preferred equalizer if it exists and was enabled last time.
-                if (SupportsEqualizer) {
-                    EqualizerManager.Instance.Select ();
-                }
-
-                if (pending_playback_for_not_ready != null) {
-                    OpenCheck (pending_playback_for_not_ready, pending_playback_for_not_ready_play);
-                    pending_playback_for_not_ready = null;
-                    pending_playback_for_not_ready_play = false;
+                if (SupportsEqualizer && EqualizerSetting.EnabledSchema.Get ()) {
+                    string name = EqualizerSetting.PresetSchema.Get();
+                    if (!String.IsNullOrEmpty (name)) {
+                        // Don't use EqualizerManager.Instance - used by the eq dialog window.
+                        EqualizerManager manager = new EqualizerManager (EqualizerManager.Instance.Path);
+                        manager.Load ();
+                        EqualizerSetting equalizer = null;
+                        foreach (EqualizerSetting eq in manager) {
+                            if (eq.Name == name) {
+                                equalizer = eq;
+                                break;
+                            }
+                        }
+                        
+                        if (equalizer != null) {
+                            Log.DebugFormat ("Enabling equalizer preset: {0}", equalizer.Name);
+                            manager.Enable (equalizer);
+                        }
+                    }
                 }
             }
-
+            
             DBusPlayerStateHandler dbus_handler = dbus_state_changed;
             if (dbus_handler != null) {
                 dbus_handler (args.Current.ToString ().ToLower ());
@@ -220,33 +194,33 @@ namespace Banshee.MediaEngine
         private void OnEngineEventChanged (PlayerEventArgs args)
         {
             if (CurrentTrack != null) {
-                if (args.Event == PlayerEvent.Error
+                if (args.Event == PlayerEvent.Error 
                     && CurrentTrack.PlaybackError == StreamPlaybackError.None) {
-                    CurrentTrack.SavePlaybackError (StreamPlaybackError.Unknown);
-                } else if (args.Event == PlayerEvent.Iterate
+                    CurrentTrack.PlaybackError = StreamPlaybackError.Unknown;
+                } else if (args.Event == PlayerEvent.Iterate 
                     && CurrentTrack.PlaybackError != StreamPlaybackError.None) {
-                    CurrentTrack.SavePlaybackError (StreamPlaybackError.None);
+                    CurrentTrack.PlaybackError = StreamPlaybackError.None;
                 }
             }
-
+            
             RaiseEvent (args);
-
+            
             // Do not raise iterate across DBus to avoid so many calls;
-            // DBus clients should do their own iterating and
+            // DBus clients should do their own iterating and 
             // event/state checking locally
             if (args.Event == PlayerEvent.Iterate) {
                 return;
             }
-
+            
             DBusPlayerEventHandler dbus_handler = dbus_event_changed;
             if (dbus_handler != null) {
-                dbus_handler (args.Event.ToString ().ToLower (),
-                    args is PlayerEventErrorArgs ? ((PlayerEventErrorArgs)args).Message : String.Empty,
+                dbus_handler (args.Event.ToString ().ToLower (), 
+                    args is PlayerEventErrorArgs ? ((PlayerEventErrorArgs)args).Message : String.Empty, 
                     args is PlayerEventBufferingArgs ? ((PlayerEventBufferingArgs)args).Progress : 0
                 );
             }
         }
-
+        
         private void OnPlayWhenIdleRequest ()
         {
             EventHandler handler = PlayWhenIdleRequest;
@@ -254,51 +228,52 @@ namespace Banshee.MediaEngine
                 handler (this, EventArgs.Empty);
             }
         }
-
+        
         private bool OnTrackIntercept (TrackInfo track)
         {
             TrackInterceptHandler handler = TrackIntercept;
             if (handler == null) {
                 return false;
             }
-
+            
             bool handled = false;
-
+            
             foreach (TrackInterceptHandler single_handler in handler.GetInvocationList ()) {
                 handled |= single_handler (track);
             }
-
+            
             return handled;
         }
-
+        
         public void Open (TrackInfo track)
         {
             OpenPlay (track, false);
         }
-
+        
         public void Open (SafeUri uri)
         {
             OpenCheck (uri);
         }
-
+        
         void IPlayerEngineService.Open (string uri)
         {
             OpenCheck (new SafeUri (uri));
         }
-
+        
         public void OpenPlay (TrackInfo track)
         {
             OpenPlay (track, true);
         }
-
+        
         private void OpenPlay (TrackInfo track, bool play)
         {
-            if (track == null || !track.CanPlay || OnTrackIntercept (track)) {
+            if (!track.CanPlay || OnTrackIntercept (track)) {
                 return;
             }
-
+        
             try {
-                OpenCheck (track, true);
+                OpenCheck (track);
+                active_engine.Play ();
             } catch (Exception e) {
                 Log.Exception (e);
                 Log.Error (Catalog.GetString ("Problem with Player Engine"), e.Message, true);
@@ -306,23 +281,17 @@ namespace Banshee.MediaEngine
                 ActiveEngine = default_engine;
             }
         }
-
+        
         private void OpenCheck (object o)
-        {
-            OpenCheck (o, false);
-        }
-
-        private void OpenCheck (object o, bool play)
         {
             if (CurrentState == PlayerState.NotReady) {
-                pending_playback_for_not_ready = o;
-                pending_playback_for_not_ready_play = play;
-                return;
+                throw new InvalidOperationException (String.Format ("Player engine {0} is in the NotReady state", 
+                    active_engine.GetType ().FullName));
             }
-
+        
             SafeUri uri = null;
             TrackInfo track = null;
-
+        
             if (o is SafeUri) {
                 uri = (SafeUri)o;
             } else if (o is TrackInfo) {
@@ -333,10 +302,10 @@ namespace Banshee.MediaEngine
             }
 
             IncrementLastPlayed ();
-
+            
             FindSupportingEngine (uri);
             CheckPending ();
-
+            
             if (track != null) {
                 active_engine.Open (track);
                 incremented_last_played = false;
@@ -344,26 +313,23 @@ namespace Banshee.MediaEngine
                 active_engine.Open (uri);
                 incremented_last_played = false;
             }
-
-            if (play) {
-                active_engine.Play ();
-            }
         }
 
         private bool incremented_last_played = true;
         public void IncrementLastPlayed ()
         {
-            if (!incremented_last_played && CurrentTrack != null && CurrentTrack.PlaybackError == StreamPlaybackError.None) {
-                //if Length <= 0 assume 100% completion:
-                if (active_engine.Length <= 0) {
-                    CurrentTrack.OnPlaybackFinished (1);
+            if (!incremented_last_played && active_engine.CurrentTrack != null) {
+                // If we're at least 50% done playing a song, mark it as played, otherwise as skipped
+                // If the Length <= 0, assume the song was finished and increment its play count
+                if (active_engine.Length <= 0 || active_engine.Position >= active_engine.Length / 2) {
+                    active_engine.CurrentTrack.IncrementPlayCount ();
                 } else {
-                    CurrentTrack.OnPlaybackFinished ((double)active_engine.Position / (double)active_engine.Length);
+                    active_engine.CurrentTrack.IncrementSkipCount ();
                 }
                 incremented_last_played = true;
             }
         }
-
+        
         private void FindSupportingEngine (SafeUri uri)
         {
             foreach (PlayerEngine engine in engines) {
@@ -378,7 +344,7 @@ namespace Banshee.MediaEngine
                     return;
                 }
             }
-
+        
             foreach (PlayerEngine engine in engines) {
                 foreach (string scheme in engine.SourceCapabilities) {
                     bool supported = scheme == uri.Scheme;
@@ -393,19 +359,19 @@ namespace Banshee.MediaEngine
                 }
             }
         }
-
+        
         public void Close ()
         {
             Close (false);
         }
-
+        
         public void Close (bool fullShutdown)
         {
             IncrementLastPlayed ();
             active_engine.Reset ();
             active_engine.Close (fullShutdown);
         }
-
+        
         public void Play ()
         {
             if (CurrentState == PlayerState.Idle) {
@@ -414,7 +380,7 @@ namespace Banshee.MediaEngine
                 active_engine.Play ();
             }
         }
-
+        
         public void Pause ()
         {
             if (!CanPause) {
@@ -423,68 +389,40 @@ namespace Banshee.MediaEngine
                 active_engine.Pause ();
             }
         }
-
-        // For use by RadioTrackInfo
-        // TODO remove this method once RadioTrackInfo playlist downloading/parsing logic moved here?
-        internal void StartSynthesizeContacting (TrackInfo track)
-        {
-            //OnStateChanged (PlayerState.Contacting);
-            RaiseEvent (new PlayerEventStateChangeArgs (CurrentState, PlayerState.Contacting));
-            synthesized_contacting_track = track;
-        }
-
-        internal void EndSynthesizeContacting (TrackInfo track, bool idle)
-        {
-            if (track == synthesized_contacting_track) {
-                synthesized_contacting_track = null;
-
-                if (idle) {
-                    RaiseEvent (new PlayerEventStateChangeArgs (PlayerState.Contacting, PlayerState.Idle));
-                }
-            }
-        }
-
+        
         public void TogglePlaying ()
         {
-            if (IsPlaying () && CurrentState != PlayerState.Paused) {
+            if (CurrentState == PlayerState.Playing) {
                 Pause ();
-            } else if (CurrentState != PlayerState.NotReady) {
+            } else {
                 Play ();
             }
         }
-
-        public void VideoExpose (IntPtr displayContext, bool direct)
+        
+        public void VideoExpose (IntPtr window, bool direct)
         {
-            active_engine.VideoExpose (displayContext, direct);
+            active_engine.VideoExpose (window, direct);
         }
-
-        public void VideoWindowRealize (IntPtr displayContext)
-        {
-            active_engine.VideoWindowRealize (displayContext);
+        
+        public IntPtr VideoWindow {
+            set { active_engine.VideoWindow = value; }
         }
-
-        public IntPtr VideoDisplayContext {
-            set { active_engine.VideoDisplayContext = value; }
-            get { return active_engine.VideoDisplayContext; }
-        }
-
+        
         public void TrackInfoUpdated ()
         {
             active_engine.TrackInfoUpdated ();
         }
-
+        
         public bool IsPlaying (TrackInfo track)
         {
             return IsPlaying () && track != null && track.TrackEqual (CurrentTrack);
         }
-
+        
         public bool IsPlaying ()
         {
-            return CurrentState == PlayerState.Playing ||
-                CurrentState == PlayerState.Paused ||
-                CurrentState == PlayerState.Loaded ||
-                CurrentState == PlayerState.Loading ||
-                CurrentState == PlayerState.Contacting;
+            return CurrentState == PlayerState.Playing || 
+                CurrentState == PlayerState.Paused || 
+                CurrentState == PlayerState.Loaded;
         }
 
         private void CheckPending ()
@@ -493,146 +431,136 @@ namespace Banshee.MediaEngine
                 if(active_engine.CurrentState == PlayerState.Idle) {
                     Close ();
                 }
-
+                
                 active_engine = pending_engine;
                 pending_engine = null;
-            }
+            } 
         }
-
+    
         public TrackInfo CurrentTrack {
-            get { return active_engine.CurrentTrack ?? synthesized_contacting_track; }
+            get { return active_engine.CurrentTrack; }
         }
-
+        
         private Dictionary<string, object> dbus_sucks;
         IDictionary<string, object> IPlayerEngineService.CurrentTrack {
-            get {
+            get { 
                 // FIXME: Managed DBus sucks - it explodes if you transport null
                 // or even an empty dictionary (a{sv} in our case). Piece of shit.
                 if (dbus_sucks == null) {
                     dbus_sucks = new Dictionary<string, object> ();
                     dbus_sucks.Add (String.Empty, String.Empty);
                 }
-
+                
                 return CurrentTrack == null ? dbus_sucks : CurrentTrack.GenerateExportable ();
             }
         }
-
+        
         public SafeUri CurrentSafeUri {
             get { return active_engine.CurrentUri; }
         }
-
+        
         string IPlayerEngineService.CurrentUri {
             get { return CurrentSafeUri == null ? String.Empty : CurrentSafeUri.AbsoluteUri; }
         }
-
+        
         public PlayerState CurrentState {
-            get { return synthesized_contacting_track != null ? PlayerState.Contacting : active_engine.CurrentState; }
+            get { return active_engine.CurrentState; }
         }
-
+        
         string IPlayerEngineService.CurrentState {
             get { return CurrentState.ToString ().ToLower (); }
         }
-
+        
         public PlayerState LastState {
             get { return active_engine.LastState; }
         }
-
+        
         string IPlayerEngineService.LastState {
             get { return LastState.ToString ().ToLower (); }
         }
-
+        
         public ushort Volume {
             get { return active_engine.Volume; }
-            set {
+            set { 
                 foreach (PlayerEngine engine in engines) {
                     engine.Volume = value;
                 }
             }
         }
-
+        
         public uint Position {
             get { return active_engine.Position; }
             set { active_engine.Position = value; }
         }
-
-        public byte Rating {
-            get { return (byte)(CurrentTrack == null ? 0 : CurrentTrack.Rating); }
-            set {
-                if (CurrentTrack != null) {
-                    CurrentTrack.Rating = (int)Math.Min (5u, value);
-                    CurrentTrack.Save ();
-                }
-            }
-        }
-
+        
         public bool CanSeek {
             get { return active_engine.CanSeek; }
         }
-
+        
         public bool CanPause {
             get { return CurrentTrack != null && !CurrentTrack.IsLive; }
         }
-
+        
         public bool SupportsEqualizer {
             get { return ((active_engine is IEqualizer) && active_engine.SupportsEqualizer); }
         }
-
-        public VideoDisplayContextType VideoDisplayContextType {
-            get { return active_engine.VideoDisplayContextType; }
+        
+        public bool SupportsVideo {
+            get { return active_engine.SupportsVideo; }
         }
-
+        
         public uint Length {
-            get {
+            get { 
                 uint length = active_engine.Length;
                 if (length > 0) {
                     return length;
-                } else if (CurrentTrack == null) {
+                } else if (active_engine.CurrentTrack == null) {
                     return 0;
                 }
-
-                return (uint) CurrentTrack.Duration.TotalSeconds;
+                
+                return (uint) active_engine.CurrentTrack.Duration.TotalSeconds;
             }
         }
-
+    
         public PlayerEngine ActiveEngine {
             get { return active_engine; }
             set { pending_engine = value; }
         }
-
+        
         public PlayerEngine DefaultEngine {
             get { return default_engine; }
-            set {
+            set { 
                 if (engines.Contains (value)) {
                     engines.Remove (value);
                 }
-
+                
                 engines.Insert (0, value);
-
+            
                 default_engine = value;
                 EngineSchema.Set (value.Id);
             }
         }
-
+        
         public IEnumerable<PlayerEngine> Engines {
             get { return engines; }
         }
-
+        
 #region Player Event System
 
         private LinkedList<PlayerEventHandlerSlot> event_handlers = new LinkedList<PlayerEventHandlerSlot> ();
-
+        
         private struct PlayerEventHandlerSlot
         {
             public PlayerEvent EventMask;
             public PlayerEventHandler Handler;
-
+            
             public PlayerEventHandlerSlot (PlayerEvent mask, PlayerEventHandler handler)
             {
                 EventMask = mask;
                 Handler = handler;
             }
         }
-
+        
         private const PlayerEvent event_all_mask = PlayerEvent.Iterate
             | PlayerEvent.StateChange
             | PlayerEvent.StartOfStream
@@ -643,38 +571,38 @@ namespace Banshee.MediaEngine
             | PlayerEvent.Volume
             | PlayerEvent.Metadata
             | PlayerEvent.TrackInfoUpdated;
-
+        
         private const PlayerEvent event_default_mask = event_all_mask & ~PlayerEvent.Iterate;
-
+        
         private static void VerifyEventMask (PlayerEvent eventMask)
         {
             if (eventMask <= PlayerEvent.None || eventMask > event_all_mask) {
                 throw new ArgumentOutOfRangeException ("eventMask", "A valid event mask must be provided");
             }
         }
-
+        
         public void ConnectEvent (PlayerEventHandler handler)
         {
             ConnectEvent (handler, event_default_mask, false);
         }
-
+        
         public void ConnectEvent (PlayerEventHandler handler, PlayerEvent eventMask)
         {
             ConnectEvent (handler, eventMask, false);
         }
-
+        
         public void ConnectEvent (PlayerEventHandler handler, bool connectAfter)
         {
             ConnectEvent (handler, event_default_mask, connectAfter);
         }
-
+        
         public void ConnectEvent (PlayerEventHandler handler, PlayerEvent eventMask, bool connectAfter)
         {
             lock (event_handlers) {
                 VerifyEventMask (eventMask);
-
+            
                 PlayerEventHandlerSlot slot = new PlayerEventHandlerSlot (eventMask, handler);
-
+                
                 if (connectAfter) {
                     event_handlers.AddLast (slot);
                 } else {
@@ -682,7 +610,7 @@ namespace Banshee.MediaEngine
                 }
             }
         }
-
+        
         private LinkedListNode<PlayerEventHandlerSlot> FindEventNode (PlayerEventHandler handler)
         {
             LinkedListNode<PlayerEventHandlerSlot> node = event_handlers.First;
@@ -692,10 +620,10 @@ namespace Banshee.MediaEngine
                 }
                 node = node.Next;
             }
-
+            
             return null;
         }
-
+        
         public void DisconnectEvent (PlayerEventHandler handler)
         {
             lock (event_handlers) {
@@ -705,12 +633,12 @@ namespace Banshee.MediaEngine
                 }
             }
         }
-
+        
         public void ModifyEvent (PlayerEvent eventMask, PlayerEventHandler handler)
         {
             lock (event_handlers) {
                 VerifyEventMask (eventMask);
-
+                
                 LinkedListNode<PlayerEventHandlerSlot> node = FindEventNode (handler);
                 if (node != null) {
                     PlayerEventHandlerSlot slot = node.Value;
@@ -719,14 +647,14 @@ namespace Banshee.MediaEngine
                 }
             }
         }
-
+        
         private void RaiseEvent (PlayerEventArgs args)
         {
             lock (event_handlers) {
                 if (args.Event == PlayerEvent.StateChange && args is PlayerEventStateChangeArgs) {
                     HandleStateChange ((PlayerEventStateChangeArgs)args);
                 }
-
+            
                 LinkedListNode<PlayerEventHandlerSlot> node = event_handlers.First;
                 while (node != null) {
                     if ((node.Value.EventMask & args.Event) == args.Event) {
@@ -738,15 +666,15 @@ namespace Banshee.MediaEngine
         }
 
 #endregion
-
+        
         string IService.ServiceName {
             get { return "PlayerEngine"; }
         }
-
-        IDBusExportable IDBusExportable.Parent {
+        
+        IDBusExportable IDBusExportable.Parent { 
             get { return null; }
         }
-
+        
         public static readonly SchemaEntry<int> VolumeSchema = new SchemaEntry<int> (
             "player_engine", "volume",
             80,
