@@ -383,18 +383,13 @@ namespace Hyena.Data.Sqlite
         
         public IEnumerable<T> FetchAllMatching (string condition, params object [] vals)
         {
-            HyenaSqliteCommand fetch_matching_command = CreateFetchCommand (condition);
+            HyenaSqliteCommand fetch_matching_command = new HyenaSqliteCommand (String.Format ("{0} AND {1}", SelectCommand.Text, condition));
             using (IDataReader reader = connection.Query (fetch_matching_command, vals)) {
                 while (reader.Read ()) {
                     yield return Load (reader);
                 }
             }
         }
-
-        public HyenaSqliteCommand CreateFetchCommand (string condition)
-        {
-            return new HyenaSqliteCommand (String.Format ("{0} AND {1}", SelectCommand.Text, condition));
-        }
         
         public IEnumerable<T> FetchRange (int offset, int limit)
         {
@@ -579,7 +574,7 @@ namespace Hyena.Data.Sqlite
         protected virtual HyenaSqliteCommand SelectRangeCommand {
             get {
                 if (select_range_command == null) {
-                    select_range_command = new HyenaSqliteCommand (
+                    select_command = new HyenaSqliteCommand (
                         String.Format (
                             "SELECT {0} FROM {1}{2}{3} LIMIT ?, ?",
                             Select, From,
@@ -675,32 +670,29 @@ namespace Hyena.Data.Sqlite
             Dictionary<string, string> tables = new Dictionary<string,string> (virtual_columns.Count + 1);
             bool first_virtual = true;
             foreach (VirtualDatabaseColumn column in virtual_columns) {
+                if (first_virtual) {
+                    first_virtual = false;
+                } else {
+                    where_builder.Append (" AND ");
+                }
                 if (first) {
                     first = false;
                 } else {
                     select_builder.Append (',');
                 }
-
                 select_builder.Append (column.TargetTable);
                 select_builder.Append ('.');
                 select_builder.Append (column.Name);
-
-                bool table_not_joined = !tables.ContainsKey (column.TargetTable);
-                if (first_virtual) {
-                    first_virtual = false;
-                } else if (table_not_joined) {
-                    where_builder.Append (" AND ");
-                }
                 
-                if (table_not_joined) {
-                    where_builder.Append (column.TargetTable);
-                    where_builder.Append ('.');
-                    where_builder.Append (column.ForeignKey);
-                    where_builder.Append (" = ");
-                    where_builder.Append (TableName);
-                    where_builder.Append ('.');
-                    where_builder.Append (column.LocalKey);
+                where_builder.Append (column.TargetTable);
+                where_builder.Append ('.');
+                where_builder.Append (column.ForeignKey);
+                where_builder.Append (" = ");
+                where_builder.Append (TableName);
+                where_builder.Append ('.');
+                where_builder.Append (column.LocalKey);
                 
+                if (!tables.ContainsKey (column.TargetTable)) {
                     tables.Add (column.TargetTable, null);
                 }
             }
