@@ -41,15 +41,22 @@ namespace Hyena.Query
     public class RelativeTimeSpanQueryValue : TimeSpanQueryValue
     {
         // The SQL operators in these Operators are reversed from normal on purpose
-        public static new readonly Operator GreaterThan        = new Operator ("greaterThan", "< {0}", ">");
-        public static new readonly Operator LessThan           = new Operator ("lessThan", "> {0}", "<");
-        public static new readonly Operator GreaterThanEqual   = new Operator ("greaterThanEquals", "<= {0}", ">=");
-        public static new readonly Operator LessThanEqual      = new Operator ("lessThanEquals", ">= {0}", "<=");
+        public static new readonly Operator GreaterThan        = new Operator ("greaterThan", Catalog.GetString ("more than"), "< {0}", true, ">");
+        public static new readonly Operator LessThan           = new Operator ("lessThan", Catalog.GetString ("less than"), "> {0}", "<");
+        public static new readonly Operator GreaterThanEqual   = new Operator ("greaterThanEquals", Catalog.GetString ("at least"), "<= {0}", true, ">=");
+        public static new readonly Operator LessThanEqual      = new Operator ("lessThanEquals", Catalog.GetString ("at most"), ">= {0}", "<=");
 
         protected static new AliasedObjectSet<Operator> operators = new AliasedObjectSet<Operator> (GreaterThan, LessThan, GreaterThanEqual, LessThanEqual);
         public override AliasedObjectSet<Operator> OperatorSet {
             get { return operators; }
         }
+        
+        public static RelativeTimeSpanQueryValue RelativeToNow (DateTime since)
+        {
+            RelativeTimeSpanQueryValue qv = new RelativeTimeSpanQueryValue ();
+            qv.SetRelativeValue ((since - DateTime.Now).TotalSeconds, TimeFactor.Second);
+            return qv;
+        }
 
         public override string XmlElementName {
             get { return "date"; }
